@@ -13,6 +13,9 @@
 from openstack.block_storage import _base_proxy
 from openstack.block_storage.v3 import availability_zone
 from openstack.block_storage.v3 import backup as _backup
+from openstack.block_storage.v3 import capabilities as _capabilities
+from openstack.block_storage.v3 import limits as _limits
+from openstack.block_storage.v3 import resource_filter as _resource_filter
 from openstack.block_storage.v3 import snapshot as _snapshot
 from openstack.block_storage.v3 import stats as _stats
 from openstack.block_storage.v3 import type as _type
@@ -384,6 +387,34 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         volume = self._get_resource(_volume.Volume, volume)
         volume.extend(self, size)
 
+    def set_volume_readonly(self, volume, readonly=True):
+        """Set a volume's read-only flag.
+
+        :param name_or_id: Name, unique ID of the volume or a volume dict.
+        :param bool readonly: Whether the volume should be a read-only volume
+            or not
+
+        :raises: OpenStackCloudTimeout if wait time exceeded.
+        :raises: OpenStackCloudException on operation error.
+        """
+        volume = self._get_resource(_volume.Volume, volume)
+        volume.set_readonly(self, readonly)
+
+    def retype_volume(self, volume, new_type, migration_policy="never"):
+        """Retype the volume.
+
+        :param name_or_id: Name, unique ID of the volume or a volume dict.
+        :param new_type: The new volume type that volume is changed with.
+        :param migration_policy: Specify if the volume should be migrated when
+                                 it is re-typed. Possible values are on-demand
+                                 or never. Default: never.
+
+        :raises: OpenStackCloudTimeout if wait time exceeded.
+        :raises: OpenStackCloudException on operation error.
+        """
+        volume = self._get_resource(_volume.Volume, volume)
+        volume.retype(self, new_type, migration_policy)
+
     def backend_pools(self):
         """Returns a generator of cinder Back-end storage pools
 
@@ -486,6 +517,28 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         backup = self._get_resource(_backup.Backup, backup)
         return backup.restore(self, volume_id=volume_id, name=name)
 
+    def get_limits(self):
+        """Retrieves limits
+
+        :returns: A Limit object, including both
+            :class:`~openstack.block_storage.v3.limits.AbsoluteLimit` and
+            :class:`~openstack.block_storage.v3.limits.RateLimit`
+        :rtype: :class:`~openstack.block_storage.v3.limits.Limit`
+        """
+        return self._get(_limits.Limit, requires_id=False)
+
+    def get_capabilities(self, host):
+        """Get a backend's capabilites
+
+        :param host: Specified backend to obtain volume stats and properties.
+
+        :returns: One :class:
+            `~openstack.block_storage.v3.capabilites.Capabilities` instance.
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        return self._get(_capabilities.Capabilities, host)
+
     def availability_zones(self):
         """Return a generator of availability zones
 
@@ -537,6 +590,13 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         """
         return resource.wait_for_delete(self, res, interval, wait)
 
+    def resource_filters(self, **query):
+        """Retrieve a generator of resource filters
+
+        :returns: A generator of resource filters.
+        """
+        return self._list(_resource_filter.ResourceFilter, **query)
+
     def _get_cleanup_dependencies(self):
         return {
             'block_storage': {
