@@ -9,19 +9,20 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import hashlib
+
 import io
 import operator
 import tempfile
+from unittest import mock
 
 from keystoneauth1 import adapter
-import mock
 import requests
-from openstack.tests.unit import base
 
 from openstack import _log
 from openstack import exceptions
 from openstack.image.v2 import image
+from openstack.tests.unit import base
+from openstack import utils
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -89,7 +90,7 @@ EXAMPLE = {
 
 
 def calculate_md5_checksum(data):
-    checksum = hashlib.md5()
+    checksum = utils.md5(usedforsecurity=False)
     for chunk in data:
         checksum.update(chunk)
     return checksum.hexdigest()
@@ -153,7 +154,7 @@ class TestImage(base.TestCase):
                               'sort_dir': 'sort_dir',
                               'sort_key': 'sort_key',
                               'status': 'status',
-                              'tag': 'tag',
+                              'tags': 'tags',
                               'updated_at': 'updated_at',
                               'visibility': 'visibility'
                               },
