@@ -10,11 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
-from openstack.tests.unit import base
+from unittest import mock
 
 from openstack.orchestration.v1 import stack_files as sf
 from openstack import resource
+from openstack.tests.unit import base
 
 FAKE = {
     'stack_id': 'ID',
@@ -26,10 +26,9 @@ class TestStackFiles(base.TestCase):
 
     def test_basic(self):
         sot = sf.StackFiles()
-        self.assertEqual('orchestration', sot.service.service_type)
         self.assertFalse(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertFalse(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertFalse(sot.allow_commit)
         self.assertFalse(sot.allow_delete)
         self.assertFalse(sot.allow_list)
 
@@ -47,7 +46,6 @@ class TestStackFiles(base.TestCase):
         sess.get = mock.Mock(return_value=resp)
 
         sot = sf.StackFiles(**FAKE)
-        sot.service = mock.Mock()
 
         req = mock.MagicMock()
         req.url = ('/stacks/%(stack_name)s/%(stack_id)s/files' %
@@ -55,7 +53,7 @@ class TestStackFiles(base.TestCase):
                     'stack_id': FAKE['stack_id']})
         mock_prepare_request.return_value = req
 
-        files = sot.get(sess)
+        files = sot.fetch(sess)
 
         sess.get.assert_called_once_with(req.url)
         self.assertEqual({'file': 'file-content'}, files)
